import React from "react"
import { graphql, useStaticQuery } from "gatsby"

import { Carousel, TitleComponent } from "@onegeo-suite/gatsby-theme-onegeo"
import { twMerge } from "tailwind-merge"

interface Props {
    options?: any
    className?: string
    delay?: number
    title?: string
}

const Partners = (props: Props) => {
    const { className = "", delay = 2000, title = "" } = props

    const dataDirectus = useStaticQuery(graphql`
        query getPartners {
            directus {
                partners(
                    filter: {
                        status: { _eq: "published" }
                        type: { _eq: "partner" }
                    }
                ) {
                    id
                    name
                    url
                    options
                    logo {
                        id
                        imageFile {
                            childImageSharp {
                                gatsbyImageData
                            }
                            name
                            publicURL
                        }
                    }
                }
            }
        }
    `)

    const partners = dataDirectus.directus.partners
    const dataImage = partners.map((partner: any) => {
        return { src: partner.logo.imageFile }
    })

    const options = props.options ?? {}
    const oClass = options.class || {}

    return (
        <div className={twMerge(className, oClass.main)}>
            {title && (
                <TitleComponent
                    title={title}
                    className="mb-6 p-2 text-2xl font-extrabold tracking-tight sm:text-3xl"
                    options={oClass.title}
                />
            )}
            <Carousel
                images={dataImage}
                isLogo={true}
                delay={delay}
                options={options.carousel}
            />
        </div>
    )
}

export default Partners
